#
# spec file for package blktrace
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?_without_docs: %global with_docs 1}
Name:           blktrace
Version:        1.3.0+git.20211021
Release:        2.2
Summary:        Block IO tracer
License:        GPL-2.0-only
Group:          Development/Tools/Other
URL:            http://git.kernel.dk/?p=blktrace.git;a=summary
Source0:        %{name}-%{version}.tar.xz
Patch0:         blkparse-track-smallest-sequence-read-per-device.patch
BuildRequires:  gcc
BuildRequires:  libaio-devel
# Required for older releases
BuildRequires:  xz
%if 0%{?with_docs}
BuildRequires:  texlive
BuildRequires:  texlive-latex
%if 0%{?suse_version} > 1220
BuildRequires:  texlive-amsfonts
BuildRequires:  texlive-cm
BuildRequires:  texlive-cm-super
BuildRequires:  texlive-dvipdfm
BuildRequires:  texlive-dvipdfmx
BuildRequires:  texlive-pdftex
BuildRequires:  tex(multirow.sty)
BuildRequires:  tex(placeins.sty)
%endif
%else
BuildRequires:  te_latex
BuildRequires:  tetex
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
blktrace is a block layer IO tracing mechanism which provides detailed
information about request queue operations up to user space. This is
valuable for diagnosing and fixing performance or application problems
relating to block layer io.

%prep
%autosetup -p1

%build
make CFLAGS="%{optflags}" all %{?with_docs: docs} -j1

%install
make DESTDIR=%{buildroot} prefix=%{_prefix} mandir=%{_mandir} install

%files
%defattr(-,root,root)
%doc README %{?with_docs: doc/blktrace.pdf btreplay/doc/btreplay.pdf btt/doc/btt.pdf}
%{_bindir}/blktrace
%{_bindir}/blkparse
%{_bindir}/btrace
%{_bindir}/blkrawverify
%{_bindir}/bno_plot.py
%{_bindir}/btt
%{_bindir}/btrecord
%{_bindir}/btreplay
%{_bindir}/verify_blkparse
%{_bindir}/blkiomon
%{_bindir}/iowatcher
%{_mandir}/man1/blkparse.1*
%{_mandir}/man1/blkrawverify.1*
%{_mandir}/man1/bno_plot.1*
%{_mandir}/man1/btt.1*
%{_mandir}/man1/iowatcher.1*
%{_mandir}/man1/verify_blkparse.1*
%{_mandir}/man8/blktrace.8*
%{_mandir}/man8/btrace.8*
%{_mandir}/man8/btrecord.8*
%{_mandir}/man8/btreplay.8*
%{_mandir}/man8/blkiomon.8*

%changelog
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Thu Oct 21 2021 jeffm@suse.com
- Update to version 1.3.0+git.20211021:
  * blkparse: fix incorrectly sized memset in check_cpu_map
  * blkparse: skip check_cpu_map with pipe input
* Mon Oct 11 2021 ddiss@suse.com
- Update to version 1.3.0+git.20210628:
  * blktrace: exit directly when nthreads_running != ncpus in run_tracers()
  * blktrace 1.3.0
  * blkparse: Print time when trace was started
  * blktrace: inclusive terminology
  * blkparse: Print PID information for TN_MESSAGE events
  * iowatcher: Handle cgroup information
  * iowatcher: Use blktrace_api.h
  * blkparse: Handle cgroup information
  * blkparse: Fix up the sector and length of split completions
  * blkparse: Initialize and test for undefined request tracking timestamps
* Mon Oct 11 2021 David Disseldorp <ddiss@suse.com>
- UsrMerge: relocate blktrace, blkparse and btrace (bsc#1191056)
* Tue Jun  5 2018 opensuse-packaging@opensuse.org
- Update to version 1.2.0+git.20180516:
  * make btt scripts python3-ready
  * btt: make device/devno use PATH_MAX to avoid overflow (bsc#1091942).
  * blkparse: add documetation for 'R' requeue request
  * blkparse: remove duplicated entry for flag M
* Tue Mar 20 2018 jeffm@suse.com
- Update to version 1.2.0+git.20180124:
  * blktrace: don't stop tracer if not setup trace successfully
  * fix parallel build failures
  * respect LDFLAGS when linking programs
  * btt: Fix overlapping IO stats.
  * btt/devs: silence warning on sprintf overflow
  * jhash: fix annoying gcc fall through warnings
  * Blktrace 1.2.0
  * blktrace: abort if device ioctl setup fails
* Fri Jul 28 2017 mpluskal@suse.com
- Update to version 1.1.0+git.20170126:
  * blktrace: Add support for sparse CPU numbers
  * blktrace: Reorganize creation of output file name
  * blktrace: Create empty output files for non-existent cpus
* Fri Nov 25 2016 mpluskal@suse.com
- Update to version 1.1.0+git.20160823:
  * Use maximum over all traces for queue depth
  * Process notify events outside of given interval
  * iowatcher: Use queue events if issue not available
  * btt: Replace overlapping IO
  * Zero sectors are strange
  * Don't prepend blktrace destination dir if we didn't run blktrace
  * Separate prefix in legend with space
  * Fixup graph name in help text
  * blktrace: remove -k from manpage synopsis
  * iowatcher: link with -lrt
* Tue Apr 26 2016 jeffm@suse.com
- Update to version 1.1.0+git.20160425:
  * Refer to sda instead of hda in man pages
  * btreplay: Fix typo in scaling up the dynamic cpu set size.
  * include sys/types.h for dev_t definition
  * Fix warnings on newer gcc
  * Add the "-a discard" filter option to the blktrace.8 man page
  * blktrace: Use number of online CPUs
  * btreplay: fix memory corruption caused by CPU_ZERO_S
  * btreplay: fix sched_{set|get}affinity
  * btreplay: make Ctrl-C work
  * btreplay: remove timestamps
* Tue Apr 26 2016 jeffm@suse.com
- Add _service for automatic git syncing
  + exclude .git when generating tarball
  + enable automatic changelog updating
* Fri Oct  3 2014 dsterba@suse.cz
- Update to 1.1.0:
  - merge iowatcher
* Sat Dec 29 2012 p.drouand@gmail.com
- Update to 1.0.5 version:
  * Fix compiler warnings
  * avoid string overflows
- Some improvements like using macro instead of RPM variables
* Mon Jul 23 2012 werner@suse.de
- Add some missed fonts
* Tue Jul 10 2012 werner@suse.de
- Make it build with latest TeXLive 2012 with new package layout
* Thu Oct 27 2011 jeffm@suse.de
- Update to v1.0.3 (bnc#720300 and others).
  - Updated documentation
  - Fixed multiple output errors
  - Added FLUSH/FUA support
  - Misc bug fixes
* Wed Sep 21 2011 coolo@suse.com
- disable parallel build again
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Sat Sep  3 2011 crrodriguez@opensuse.org
- Fix build with no-add-needed (missing -pthread)
* Thu Oct 15 2009 marek.belisko@open-nandra.com
- Fix memory leak (bnc #546035)
* Tue Jul 21 2009 jblunck@suse.de
- Fix memory leak in btrecord (bnc #523444).
* Tue Jun 16 2009 jblunck@suse.de
- Fix typo in btt (bnc #511264).
* Fri May 29 2009 jblunck@suse.de
- Update to version 1.0.1:
  * blkrawverify: warn and return error if no traces are found
  * blkiomon manpage and usage reference invalid "msg-queue-name" option
  * fix up btrace options & manpage
  * more manpage fixups
  * fix max-pkts option inconsistencies
  * Converted to using the correct remap entries
  * blkiomon: fix unaligned accesses on ia64
  * fix off-by-one issues in blkiomon.h
  * fix include statement in stats.h
  * handle race to mkdir at startup
  * Fixed plug/unplug logic in btt
  * Working on fixing %% time q plugged
  * fix trivial typo in manpage
  * Add NOTIFY to activity mask
  * Blktrace failed to lock reader threads on the cpu used by the
    corresponding writer. This resulted in stale data being consumed when
    blktrace accidently read at a position that was being written to at the
    same time. This issue surfaced as "bad trace magic" warnings emitted by
    blktrace tools.
  * Generate matplotlib plots for btt generated data
  * Update Jenkins hash to lookup3() variant
  * Fixed EAGAIN handling in blktrace.c
  * O_NOATIME isn't always present
  * btt: Added no remap option
  * btt general cleanup plus valgrind clean
  * btt: Missed fopen conversion to my_fopen
  * Code review updates
  * Reworked blktrace master/thread interface
  * Cleaned up devs that have no data
  * Moved starting of tracing after tracers are going
  * btt: fixed open in setup_ifile
  * Synchronized trace gathering
  * Invoke gethostbyname once, handle errors better
  * Added accept as a system call needing resource increases
  * Rewrote blktrace to have a single thread per CPU
  * Fix btt to handle large numbers of output files
  * Increased limits to allow for large system runs
  * A couple of min-counters weren't initialised correctly (thrput_r,
    thrput_w). We have got a perfectly working init function for this
    purpose. Removing partially duplicated code.
  * The git commit 11914a53d2ec2974a565311af327b8983d8c820d added
    __BLK_TA_ABORT to blktrace_api.h. A corresponding addition to the blktrace
    tools repository has been missing, breaking the API. Blkparse complained:
    "Bad fs action 40010011"
  * Added no messages option to blkparse.c
  * gcc 4.3.2 has started to warn about:
  * Added -P to create a data file w/ Q, D and C per line
  * Fixed 'M' displays on per-io output and added in I/O separator
  * Fixed segfault in aqd.c : need to check for NULL (not requested)
  * Added in -z to provide running waiting-for-issue latencies
  * Moved btrecord/btreplay to version 1.0.0
* Thu Apr 30 2009 jblunck@suse.de
- Build with docs by default.
* Tue Feb 10 2009 jblunck@suse.de
- Added missing pdf documentation for btt and btreplay (bnc #465134).
* Tue Dec  9 2008 jblunck@suse.de
- blkparse: Track smallest sequence read per device
* Mon Dec  8 2008 jblunck@suse.de
- Fix for "Bad fs action 40010011" messages (bnc #450909).
* Tue Nov  4 2008 jblunck@suse.de
- Update to version 1.0.0:
  * Update rbtree to version with unified parent + color
  * blkiomon: add through-put statistics
  * blkiomon: separate statistics for read and write requests
  * blkiomon: fix some debug messages
  * blkiomon: fix trace debug output
  * blkiomon: fix unit in histogram output
  * blkiomon: fix cross-arch data analysis issue
  * blkiomon: drv_data traces pass-through
  * blkparse: add hint for discarded drv_data traces
  * Added in -L option - output periodic latency information
  * Added in -Q / --active-queue-depth option
  * Add driver data support
  * blktrace: accept -v (lower case) for version info as well
  * blkiomon: I/O monitor
  * Removed excessive amounts of seek modes (for random sets of I/Os)
  * spec file tweak
  * man page typo
  * Added in %%done for btt
  * Add documentation of 'D' discard operation
  * blktrace: support discard requests
  * spelling and grammar fixes for btreplay.tex
  * Put message notes from kernel into a separate file for easy tracking
  * Added in new message updates to the documentation.
  * Added in handling of MESSAGE notes
  * Handled no difference in seek times
  * Added in -m option, seeks-per-second
  * blkparse: cope with missing process notify event
  * Fixed percentage calculations for phases of an I/O
  * Added S2G times + fixed up -X output to include X2X
  * Added -X option - generate easily parseable file
  * Add -x accellerator option
  * Fix problem with -w option
  * eliminate check of empty -F format
  * blkparse: Introduce optional accounting of PC requests
  * blkparse: Add PC requests to depth trace
  * Fix section of btrecord and btreplay man pages
  * Don't like btrecord against libaio and librt, as it doesn't use any of
    their symbols
  * Really commit the changes to btt.1
  * Added man page for bno_plot and updated btt man page to refer to bno_plot
  * Cleanups: Fixed IOPs in btt left over at end of run
  * btt: fix missing cleanup call
  * btt: fix iostat interval default
  * Added info about bno_plot.py and clean ups
  * Added new IOs per unplug table
  * Added bno_plot.py - generate interactive 3D plot of IO blocks and sizes
* Fri Oct 24 2008 jblunck@suse.de
- Add two additional patches for my friend Gerald (bnc #433433):
  * blkparse: Introduce optional accounting of PC requests
  * blkparse: Add PC requests to depth trace
* Mon Sep 15 2008 jjolly@suse.de
- Added blkiomon and manpage to specfile
* Fri Sep 12 2008 jjolly@suse.de
- Added patches for FCP performance data collection (bnc#417241)
* Mon May 19 2008 jblunck@suse.de
- cope with missing process notify event which could otherwise segfault
* Fri Feb  1 2008 jblunck@suse.de
- Update to commit 00a47cd169f2cc87b5f63fe93226b7231dee678c
  * Fixed excess bucket information for unplug histograms
  * UNPLUG does the timing stuff, UNPLUG TIMEOUT only does timeout
* Tue Jan 22 2008 jblunck@suse.de
- Update to commit 461afe819c41fa811f9c6264524cb8edbd2acc63:
  * Fix Q counts during requeue and merges
  * Separated out g/i/m trace handling
  * btreplay/btrecord man pages
  * Remove strange make dependency
  * Added in Q2D histograms (requires -A)
  * memset() must be done after NULL check
  * Added active requests at Q information
  * Fixed REMAP to update Q2A & fixed #Q calculations
  * blktrace segfault
  * Added O_NOATIME to replay file
  * Fix segfault in replay_sub when verbose is 1
  * Converted fatal to an inline function
  * Converted fatal from macro to inline
  * Add btrecord/btreplay capability
  * Added list_splice to btt/list.h
  * btt manpages
  * Fix compilation on m68k
  * Major revamping (ver 2.0)
* Wed Aug 29 2007 jblunck@suse.de
- Update to 0.99.3:
  * fix indent typo
  * man page: mention buffer size / number of buffers defaults
  * Makefile fixes
* Sun Aug 26 2007 jblunck@suse.de
- Initial openSUSE package
* Mon Oct 10 2005 axboe@suse.de
- Initial version
